@@ -7,7 +7,7 @@ calc_total_clearance<- function(chem.cas=NULL,chem.name=NULL,parameters=NULL,spe
     if(is.null(parameters)) parameters <- parameterize_steadystate(chem.cas=chem.cas, chem.name=chem.name, species=species,default.to.human=default.to.human)
     Qgfrc <- get_param("Qgfrc",parameters,"calc_Css") / parameters[['BW']]^0.25 #L/h/kgBW
     fub <- get_param("Funbound.plasma",parameters,"calc_Css") # unitless fraction
-    clearance <- Qgfrc*fub+calc_hepatic_clearance(parameters=parameters,suppress.messages=T) #L/h/kgBW
+    clearance <- Qgfrc*fub+calc_hepatic_clearance(chem.cas=chem.cas,chem.name=chem.name,species=species,parameters=parameters,suppress.messages=T) #L/h/kgBW
     if(!suppress.messages)cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"total clearance returned in units of L/h/kg BW.\n")
     return(as.numeric(clearance))
 }
\ No newline at end of file
