@@ -19,7 +19,7 @@ calc_vdist<- function(chem.cas=NULL,
   else schmitt.params <- F                                                                                            
 
   if(schmitt.params & !('funbound.plasma' %in% tolower(names(parameters)))){
-    if(is.null(chem.cas) & is.null(chem.name))stop("Specify chem.name or chem.cas if not including Funbound.plasma with predict_partitioning_schmitt coefficients.")
+    if(is.null(chem.cas) & is.null(chem.name))stop("Specify chem.name or chem.cas with correct species if not including Funbound.plasma with predict_partitioning_schmitt coefficients.")
     else if(is.null(chem.cas)){
       out <- get_chem_id(chem.cas=chem.cas,chem.name=chem.name)
       chem.cas <- out$chem.cas
@@ -86,7 +86,9 @@ calc_vdist<- function(chem.cas=NULL,
     }
   }
     
-  if(!suppress.messages)cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"volume of distribution returned in units of L/kg BW.\n")
-    
+  if(!suppress.messages){
+    if(is.null(chem.name) & is.null(chem.cas)) cat("Volume of distribution returned in units of L/kg BW.\n")
+    else cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"volume of distribution returned in units of L/kg BW.\n")
+  } 
   return(as.numeric(vol.dist))
 }
\ No newline at end of file
